@@ -33,11 +33,19 @@ meta
 ## -----------------------------------------------------------------------------
 x <- data.frame(ID = 1, CONC = 1, RACE = 1)
 x <- decorate(x, meta = meta)
-str(x)
+decorations(x)
 
 ## -----------------------------------------------------------------------------
-# decorations(x) # just a list
-as_yamlet(x) # a list with class 'yamlet' (special print method)
+x <- data.frame(ID = 1, CONC = 1, RACE = 1)
+x <- decorate(x,'
+ID: subject identifier
+CONC: [ concentration, ng/mL ]
+RACE: [ race, [white: 0, black: 1, asian: 2 ]]
+')
+decorations(x)
+
+## -----------------------------------------------------------------------------
+decorations(x)
 
 ## -----------------------------------------------------------------------------
 file <- file.path(tempdir(), 'out.yaml')
@@ -72,9 +80,9 @@ library(magrittr)
 file <- system.file(package = 'yamlet', 'extdata','quinidine.csv')
 
 file %>% 
-  decorate %>%
-  filter(!is.na(conc)) %>%
-  ggready(parse = FALSE) %>%
+  decorate %>% 
+  filter(!is.na(conc)) %>% 
+  resolve %>%
   ggplot(aes(x = time, y = conc, color = Heart)) + 
   geom_point()
 
